GeometryTypeAndDimensions

Struct GeometryTypeAndDimensions 

pub struct GeometryTypeAndDimensions { /* private fields */ }
Geometry type and dimension

Combines a GeometryTypeId with Dimensions to handle cases where these concepts are represented together (e.g., GeoParquet geometry types, WKB geometry type integers, Parquet GeoStatistics). For sanity’s sake, this combined concept is also frequently just called “geometry type”.

Implementations

Source

impl GeometryTypeAndDimensions

pub fn new(geometry_type: GeometryTypeId, dimensions: Dimensions) -> Self

Create from GeometryTypeId and Dimensions

pub fn try_from_geom( geom: &impl GeometryTrait, ) -> Result<Self, SedonaGeometryError>

Create from GeometryTrait

pub fn geometry_type(&self) -> GeometryTypeId

pub fn dimensions(&self) -> Dimensions

pub fn try_from_wkb_id(wkb_id: u32) -> Result<Self, SedonaGeometryError>

Create from an ISO WKB integer identifier (e.g., 1001 for Point Z)

pub fn wkb_id(&self) -> u32

ISO WKB integer identifier (e.g., 1001 for Point Z)

pub fn geojson_id(&self) -> String

GeoJSON/GeoParquet identifier (e.g., Point Z, LineString, Polygon ZM)