pub enum GeometryTypeId {
Geometry,
Point,
LineString,
Polygon,
MultiPoint,
MultiLineString,
MultiPolygon,
GeometryCollection,
}Expand description
Geometry types
An enumerator for the set of natively supported geometry types without considering Dimensions. See GeometryTypeAndDimensions for a struct to track both.
This is named GeometryTypeId such that it does not conflict with geo_traits::GeometryType.
Variants
Geometry
Unknown or mixed geometry type
Point
Point geometry type
LineString
LineString geometry type
Polygon
Polygon geometry type
MultiPoint
MultiPoint geometry type
MultiLineString
MultiLineString geometry type
MultiPolygon
MultiPolygon geometry type
GeometryCollection
GeometryCollection geometry type
Implementations
Sourceimpl GeometryTypeId
impl GeometryTypeId
Sourcepub fn try_from_wkb_id(wkb_id: u32) -> Result<Self, SedonaGeometryError>
pub fn try_from_wkb_id(wkb_id: u32) -> Result<Self, SedonaGeometryError>
Construct a geometry type from a WKB type integer
Parses the geometry type (not dimension) component of a WKB type code (e.g., 1 for Point…7 for GeometryCollection).
Sourcepub fn wkb_id(&self) -> u32
pub fn wkb_id(&self) -> u32
WKB integer identifier
The GeometryType portion of the WKB identifier (e.g., 1 for Point…7 for GeometryCollection).
Sourcepub fn geojson_id(&self) -> &'static str
pub fn geojson_id(&self) -> &'static str
GeoJSON/GeoParquet string identifier
The identifier used by GeoJSON and GeoParquet to refer to this geometry type. Use FromStr to parse such a string back into a GeometryTypeId.