pub struct GeometryTypeAndDimensions { /* private fields */ }Expand description
Geometry type and dimension
Combines a GeometryTypeId with Dimensions to handle cases where these concepts are represented together (e.g., GeoParquet geometry types, WKB geometry type integers, Parquet GeoStatistics). For sanity’s sake, this combined concept is also frequently just called “geometry type”.
Implementations
Sourceimpl GeometryTypeAndDimensions
impl GeometryTypeAndDimensions
Sourcepub fn new(geometry_type: GeometryTypeId, dimensions: Dimensions) -> Self
pub fn new(geometry_type: GeometryTypeId, dimensions: Dimensions) -> Self
Create from GeometryTypeId and Dimensions
Sourcepub fn try_from_geom(
geom: &impl GeometryTrait,
) -> Result<Self, SedonaGeometryError>
pub fn try_from_geom( geom: &impl GeometryTrait, ) -> Result<Self, SedonaGeometryError>
Create from GeometryTrait
Sourcepub fn geometry_type(&self) -> GeometryTypeId
pub fn geometry_type(&self) -> GeometryTypeId
The GeometryTypeId
Sourcepub fn dimensions(&self) -> Dimensions
pub fn dimensions(&self) -> Dimensions
The Dimensions
Sourcepub fn try_from_wkb_id(wkb_id: u32) -> Result<Self, SedonaGeometryError>
pub fn try_from_wkb_id(wkb_id: u32) -> Result<Self, SedonaGeometryError>
Create from an ISO WKB integer identifier (e.g., 1001 for Point Z)
Sourcepub fn geojson_id(&self) -> String
pub fn geojson_id(&self) -> String
GeoJSON/GeoParquet identifier (e.g., Point Z, LineString, Polygon ZM)